"""
Communication CLI commands for the Konigle SDK.

This module provides CLI commands for managing email, SMS, WhatsApp,
and other communication channels.
"""

# Import email commands to register them
from . import email  # noqa